==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/intents/INPlayMediaIntentResponseCode.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.intents;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.eventkit.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 12.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/INPlayMediaIntentResponseCode/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Unspecified(0L),
    Ready(1L),
    ContinueInApp(2L),
    InProgress(3L),
    Success(4L),
    HandleInApp(5L),
    Failure(6L),
    FailureRequiringAppLaunch(7L),
    FailureUnknownMediaType(8L),
    FailureNoUnplayedContent(9L),
    FailureRestrictedContent(10L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/INPlayMediaIntentResponseCode/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/INPlayMediaIntentResponseCode/*</name>*/ valueOf(long n) {
        for (/*<name>*/INPlayMediaIntentResponseCode/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/INPlayMediaIntentResponseCode/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/intents/INPlayMediaIntentResponseCode.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.intents;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.eventkit.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 12.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/INPlayMediaIntentResponseCode/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Unspecified(0L),
    Ready(1L),
    ContinueInApp(2L),
    InProgress(3L),
    Success(4L),
    HandleInApp(5L),
    Failure(6L),
    FailureRequiringAppLaunch(7L),
    FailureUnknownMediaType(8L),
    FailureNoUnplayedContent(9L),
    FailureRestrictedContent(10L),
    /**
     * @since Available in iOS 15.4 and later.
     */
    FailureMaxStreamLimitReached(11L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/INPlayMediaIntentResponseCode/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/INPlayMediaIntentResponseCode/*</name>*/ valueOf(long n) {
        for (/*<name>*/INPlayMediaIntentResponseCode/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/INPlayMediaIntentResponseCode/*</name>*/.class.getName());
    }
}
